pub struct RawArticle {
pub link: String,
pub title: String,
pub publish_date: DateTime<Utc>,
pub source: String,
pub language: String,
pub summary: Option<String>,
pub images: Vec<String>,
pub created_at: Option<DateTime<Utc>>,
pub revised_date: Option<DateTime<Utc>>,
pub is_update: Option<bool>,
pub categories: Vec<String>,
}Expand description
An unenriched article as delivered by the raw WebSocket stream (no sentiment, entities, or content — lower latency).
Fields
link: StringCanonical URL of the article.
title: StringHeadline.
publish_date: DateTime<Utc>Publication timestamp.
source: StringSource domain.
language: StringISO 639-1 language code.
summary: Option<String>Article summary.
images: Vec<String>Image URLs.
created_at: Option<DateTime<Utc>>When finlight first stored the article.
revised_date: Option<DateTime<Utc>>When the article was last revised by its publisher.
is_update: Option<bool>Whether this delivery is an update to a previously seen article.
categories: Vec<String>Categories assigned by finlight’s classification.